==> eiffelstudio-18.01.10.1424.tar: F_code/C1/ar26.c <==
/*
 * Code for class ARGUMENT_TERMINAL_SOURCE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ar26.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ARGUMENT_TERMINAL_SOURCE}.arguments */
static EIF_REFERENCE F38_513_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEV;
	RTGC;
	RTOSP (513);
#define Result RTOSR(513)
	RTOC_NEW(Result);
	loc1 = F436_2412(RTCV(RTOSCF(514,F38_514,(Current))));
	loc2 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_0_);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,639,0xFF01,793,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 639, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F640_2847(RTCW(tr1), loc2);
	Result = (EIF_REFERENCE) tr1;
	loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc3 > loc2)) break;
		tr1 = F575_2648(RTCW(loc1), loc3);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R907[Dtype(Result)-242])(RTCW(Result), tr1);
		loc3++;
	}
	RTOSE (513);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F38_513 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(513,F38_513_body,(Current));
}

/* {ARGUMENT_TERMINAL_SOURCE}.terminal_arguments */
static EIF_REFERENCE F38_514_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (514);
#define Result RTOSR(514)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(435, 0x01).id, 435, _OBJSIZ_0_0_0_0_0_0_0_0_);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (514);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F38_514 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(514,F38_514_body,(Current));
}

void EIF_Minit26 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C1/ar26.c <==
/*
 * Code for class ARGUMENT_TERMINAL_SOURCE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ar26.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ARGUMENT_TERMINAL_SOURCE}.arguments */
static EIF_REFERENCE F38_531_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEV;
	RTGC;
	RTOSP (531);
#define Result RTOSR(531)
	RTOC_NEW(Result);
	loc1 = F240_1974(RTCV(RTOSCF(532,F38_532, (Current))));
	loc2 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_0_);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,641,0xFF01,798,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 641, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F642_2894(RTCW(tr1), loc2);
	Result = (EIF_REFERENCE) tr1;
	loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc3 > loc2)) break;
		tr1 = F577_2691(RTCW(loc1), loc3);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R1929[Dtype(RTCW(Result))-641])(Result, tr1);
		loc3++;
	}
	RTOSE (531);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F38_531 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(531,F38_531_body,(Current));
}

/* {ARGUMENT_TERMINAL_SOURCE}.terminal_arguments */
static EIF_REFERENCE F38_532_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (532);
#define Result RTOSR(532)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(239, 0x01).id, 239, _OBJSIZ_0_0_0_0_0_0_0_0_);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (532);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F38_532 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(532,F38_532_body,(Current));
}

void EIF_Minit26 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
